==> estateplat-common-1.2.3-20180103.011847-2-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyryxyjl.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;

import java.util.Date;

import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/10/25
 * @description 从业人员信用记录
 */
@Table(name = "fcjy_cyzt_cyryxyjl")
public class FcjyCyztCyryxyjl implements InsertVo {
    @Id
    private String xyjlid;//主键
    private String xyjlbh;//信用记录编号
    private String xyjllx;//信用记录类型
    private Double xyjlfz;//信用记录分值
    private String ryid;//人员id
    private String jlry;//记录人员
    private Date jlsj;//记录时间
    private String bz;//备注

    public String getXyjlid() {
        return xyjlid;
    }

    public void setXyjlid(String xyjlid) {
        this.xyjlid = xyjlid;
    }

    public String getXyjlbh() {
        return xyjlbh;
    }

    public void setXyjlbh(String xyjlbh) {
        this.xyjlbh = xyjlbh;
    }

    public String getXyjllx() {
        return xyjllx;
    }

    public void setXyjllx(String xyjllx) {
        this.xyjllx = xyjllx;
    }

    public Double getXyjlfz() {
        return xyjlfz;
    }

    public void setXyjlfz(Double xyjlfz) {
        this.xyjlfz = xyjlfz;
    }

    public String getRyid() {
        return ryid;
    }

    public void setRyid(String ryid) {
        this.ryid = ryid;
    }

    public String getJlry() {
        return jlry;
    }

    public void setJlry(String jlry) {
        this.jlry = jlry;
    }

    public Date getJlsj() {
        return jlsj;
    }

    public void setJlsj(Date jlsj) {
        this.jlsj = jlsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20190822.071022-225-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyryxyjl.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;

import java.util.Date;

import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/10/25
 * @description 从业人员信用记录
 */
@Table(name = "fcjy_cyzt_cyryxyjl")
public class FcjyCyztCyryxyjl implements InsertVo {
    @Id
    private String xyjlid;//主键
    private Long xyjlbh;//信用记录编号
    private String xyjllx;//信用记录类型
    private Double xyjlfz;//信用记录分值
    private String ryid;//人员id
    private String jlry;//记录人员
    private Date jlsj;//记录时间
    private String bz;//备注

    public String getXyjlid() {
        return xyjlid;
    }

    public void setXyjlid(String xyjlid) {
        this.xyjlid = xyjlid;
    }

    public Long getXyjlbh() {
        return xyjlbh;
    }

    public void setXyjlbh(Long xyjlbh) {
        this.xyjlbh = xyjlbh;
    }

    public String getXyjllx() {
        return xyjllx;
    }

    public void setXyjllx(String xyjllx) {
        this.xyjllx = xyjllx;
    }

    public Double getXyjlfz() {
        return xyjlfz;
    }

    public void setXyjlfz(Double xyjlfz) {
        this.xyjlfz = xyjlfz;
    }

    public String getRyid() {
        return ryid;
    }

    public void setRyid(String ryid) {
        this.ryid = ryid;
    }

    public String getJlry() {
        return jlry;
    }

    public void setJlry(String jlry) {
        this.jlry = jlry;
    }

    public Date getJlsj() {
        return jlsj;
    }

    public void setJlsj(Date jlsj) {
        this.jlsj = jlsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
